@@ -1,3 +1,5 @@
+testthat::skip_on_cran()
+testthat::skip_on_ci()
 test_that("noaa api", {
 
   clat <- 48.8146
